@@ -54,8 +54,8 @@ extern int cursorcolortable[];
 extern int exitprogram;
 extern int eacolumn;
 extern int eamode;
-extern int keypreset;
-extern int playerversion;
+extern unsigned keypreset;
+extern unsigned playerversion;
 extern int fileformat;
 extern int zeropageadr;
 extern int playeradr;
@@ -77,23 +77,23 @@ extern unsigned catweasel;
 extern unsigned interpolate;
 extern unsigned hardsidbufinteractive;
 extern unsigned hardsidbufplayback;
-extern char *configptr;
 extern char configbuf[MAX_PATHNAME];
-extern unsigned char loadedsongfilename[MAX_FILENAME];
-extern unsigned char songfilename[MAX_FILENAME];
-extern unsigned char songfilter[MAX_FILENAME];
-extern unsigned char songpath[MAX_PATHNAME];
-extern unsigned char instrfilename[MAX_FILENAME];
-extern unsigned char instrfilter[MAX_FILENAME];
-extern unsigned char instrpath[MAX_PATHNAME];
-extern unsigned char packedpath[MAX_PATHNAME];
+extern char loadedsongfilename[MAX_FILENAME];
+extern char songfilename[MAX_FILENAME];
+extern char songfilter[MAX_FILENAME];
+extern char songpath[MAX_PATHNAME];
+extern char instrfilename[MAX_FILENAME];
+extern char instrfilter[MAX_FILENAME];
+extern char instrpath[MAX_PATHNAME];
+extern char packedpath[MAX_PATHNAME];
 extern char *programname;
 extern char textbuffer[MAX_PATHNAME];
 extern unsigned char hexkeytbl[16];
 extern unsigned char datafile[];
 #endif
 
-void getparam(FILE *handle, int *value);
+void getparam(FILE *handle, unsigned *value);
+void getfloatparam(FILE *handle, float *value);
 void waitkey(void);
 void waitkeymouse(void);
 void waitkeynoupdate(void);
